@@ -11,9 +11,15 @@ import re
 from django import template
 from django.conf import settings
 from django.template import Node, Variable, TemplateSyntaxError, TemplateDoesNotExist
-from django.template.loader import get_template_from_string, find_template_source
+from django.template.loader import get_template_from_string
 from django.template.loader_tags import BlockNode
 
+# Backwards compatibility with Django 1.1
+try:
+    from django.template.loader import find_template
+except ImportError:
+    from django.template.loader import find_template_source as find_template
+
 """
 This module adds support for hook tag which allows doing magic like this:
 
@@ -84,7 +90,7 @@ class HookNode(Node):
 
             else:
                 try:
-                    source, origin = find_template_source(path)
+                    source, origin = find_template(path)
                     addon_template = get_template_from_string(source, origin, template)
                     template_cache[path] = addon_template
                 except TemplateDoesNotExist:
